==> dvc-0.94.0-py37hc8dfbb8_1.tar.bz2: Lib/site-packages/dvc/command/imp_url.py <==
import argparse
import logging

from dvc.command.base import append_doc_link
from dvc.command.base import CmdBase
from dvc.exceptions import DvcException


logger = logging.getLogger(__name__)


class CmdImportUrl(CmdBase):
    def run(self):
        try:
            self.repo.imp_url(
                self.args.url, out=self.args.out, fname=self.args.file
            )
        except DvcException:
            logger.exception(
                "failed to import {}. You could also try downloading "
                "it manually, and adding it with `dvc add`.".format(
                    self.args.url
                )
            )
            return 1
        return 0


def add_parser(subparsers, parent_parser):
    IMPORT_HELP = (
        "Download or copy file from URL and take it under DVC control."
    )

    import_parser = subparsers.add_parser(
        "import-url",
        parents=[parent_parser],
        description=append_doc_link(IMPORT_HELP, "import-url"),
        help=IMPORT_HELP,
        formatter_class=argparse.RawTextHelpFormatter,
    )
    import_parser.add_argument(
        "url",
        help="Supported urls:\n"
        "/path/to/file\n"
        "/path/to/directory\n"
        "C:\\\\path\\to\\file\n"
        "C:\\\\path\\to\\directory\n"
        "https://example.com/path/to/file\n"
        "s3://bucket/path/to/file\n"
        "s3://bucket/path/to/directory\n"
        "gs://bucket/path/to/file\n"
        "gs://bucket/path/to/directory\n"
        "hdfs://example.com/path/to/file\n"
        "ssh://example.com:/path/to/file\n"
        "ssh://example.com:/path/to/directory\n"
        "remote://myremote/path/to/file (see `dvc remote`)",
    )
    import_parser.add_argument(
        "out", nargs="?", help="Destination path to put files to."
    )
    import_parser.add_argument(
        "-f",
        "--file",
        help="Specify name of the DVC-file this command will generate.",
        metavar="<filename>",
    )
    import_parser.set_defaults(func=CmdImportUrl)

==> dvc-1.1.1-py37hc8dfbb8_0.tar.bz2: Lib/site-packages/dvc/command/imp_url.py <==
import argparse
import logging

from dvc.command import completion
from dvc.command.base import CmdBase, append_doc_link
from dvc.exceptions import DvcException

logger = logging.getLogger(__name__)


class CmdImportUrl(CmdBase):
    def run(self):
        try:
            self.repo.imp_url(
                self.args.url,
                out=self.args.out,
                fname=self.args.file,
                no_exec=self.args.no_exec,
            )
        except DvcException:
            logger.exception(
                "failed to import {}. You could also try downloading "
                "it manually, and adding it with `dvc add`.".format(
                    self.args.url
                )
            )
            return 1
        return 0


def add_parser(subparsers, parent_parser):
    IMPORT_HELP = (
        "Download or copy file from URL and take it under DVC control."
    )

    import_parser = subparsers.add_parser(
        "import-url",
        parents=[parent_parser],
        description=append_doc_link(IMPORT_HELP, "import-url"),
        help=IMPORT_HELP,
        formatter_class=argparse.RawTextHelpFormatter,
    )
    import_parser.add_argument(
        "url",
        help="Supported urls:\n"
        "/path/to/file\n"
        "/path/to/directory\n"
        "C:\\\\path\\to\\file\n"
        "C:\\\\path\\to\\directory\n"
        "https://example.com/path/to/file\n"
        "s3://bucket/path/to/file\n"
        "s3://bucket/path/to/directory\n"
        "gs://bucket/path/to/file\n"
        "gs://bucket/path/to/directory\n"
        "hdfs://example.com/path/to/file\n"
        "ssh://example.com:/path/to/file\n"
        "ssh://example.com:/path/to/directory\n"
        "remote://myremote/path/to/file (see `dvc remote`)",
    )
    import_parser.add_argument(
        "out",
        nargs="?",
        help="Destination path to put files to.",
        metavar="out",
        choices=completion.Optional.DIR,
    )
    import_parser.add_argument(
        "--file",
        help="Specify name of the DVC-file this command will generate.",
        metavar="<filename>",
        choices=completion.Optional.DIR,
    )
    import_parser.add_argument(
        "--no-exec",
        action="store_true",
        default=False,
        help="Only create DVC-file without actually downloading it.",
    )
    import_parser.set_defaults(func=CmdImportUrl)
